PROCLITICS = {
    "ὁ", "ἡ", "οἱ", "αἱ",
    "ἐν", "εἰς", "ἐξ", "ἐκ",
    "εἰ", "ὡς",
    "οὐ", "οὐκ", "οὐχ",
}


ENCLITICS = {
    # personal pronouns
    "μου", "μοι", "με",
    "σου", "σοι", "σε",

    # indefinite pronouns
    "τὶς", "τὶ", "τινός", "τινί", "τινά", "τινές", "τινάς", "τινῶν", "τισίν",
    "τισί",

    # indefinite adverbs
    "πού", "ποτέ", "πώ", "πώς",

    # dissyllabic forms of εἰμί
    "εἰμί", "εἰσίν", "εἰσί", "ἐσμέν", "ἐστέ", "ἐστίν", "ἐστί",

    # dissyllabic forms of φημί
    "φησίν", "φημί", "φασίν",

    # certain particles
    "γέ", "τέ", "τοι",
}


ELISION = {
    "ἀλλ’": "ἀλλά",
    "ἀνθ’": "ἀντί",
    "ἀπ’": "ἀπό",
    "ἀφ’": "ἀπό",
    "γ’": "γε",
    "γένοιτ’": "γένοιτο",
    "δ’": "δέ",
    "δεῦρ’": "δεῦρο",
    "δι’": "διά",
    "δύναιτ’": "δύναιτο",
    "εἶτ’": "εἶτα",
    "ἐπ’": "ἐπί",
    "ἔτ’": "ἔτι",
    "ἐφ’": "ἐπί",
    "ἡγοῖντ’": "ἡγοῖντο",
    "ἵν’": "ἵνα",
    "καθ’": "κατά",
    "κατ’": "κατά",
    "μ’": "με",
    "μεθ’": "μετά",
    "μετ’": "μετά",
    "μηδ’": "μηδέ",
    "μήδ’": "μηδέ",  # @@@
    "ὅτ’": "ὅτε",
    "οὐδ’": "οὐδέ",
    "πάνθ’": "πάντα",
    "πάντ’": "πάντα",
    "παρ’": "παρά",
    "ποτ’": "ποτε",
    "σ’": "σε",
    "τ’": "τε",
    "ταῦθ’": "ταῦτα",
    "ταῦτ’": "ταῦτα",
    "τοῦτ’": "τοῦτο",
    "ὑπ’": "ὑπό",
    "ὑφ’": "ὑπό",
    # "ἔσθ’": "???",
    # "θεῖ’": "???",
}

MOVABLE = {
    "ἐξ": "ἐκ",

    "οὐκ": "οὐ",
    "οὐχ": "οὐ",
}
